<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://entusiastics.com
 * @since      1.0.0
 *
 * @package    Entusiastics_Quiz_Game
 * @subpackage Entusiastics_Quiz_Game/admin/partials
 */


?>

<div class="wrap">

	<h1 class="wp-heading-inline">
		<?php printf(__('Quiz Completado', 'entusiastics-quiz-game'), $args['quiz']->title)?>
	</h1>

	<ul class="header-links-list">

		<li>
			<a href="admin.php?page=entusiastics-quiz-game-completed-list">
				<?php _e('Volver a los completados', 'entusiastics-quiz-game') ?>
			</a>
		</li>
		<span>|</span>
		<li>	
			<a href="admin.php?page=entusiastics-quiz-game-quizzes&action=edit&id=<?php echo $args['quiz']->id?>">
				<?php _e('Editar este Quiz', 'entusiastics-quiz-game')?>
			</a>
		</li>
		<span>|</span>
		<li>	
			<a href="admin.php?page=entusiastics-quiz-game-questions&quiz_id=<?php echo $args['quiz']->id?>">
				<?php _e('Administar preguntas', 'entusiastics-quiz-game')?>
			</a>
		</li>

	</ul>

	<hr class="wp-header-end">
	
	<div class="postbox-container" style="width:100%;">

		<h2 class="entusiastics-result-title">
			<?php _e('General', 'entusiastics-quiz-game') ?>
		</h2>

		<table class="form-table fixed">

			<tbody>

				<tr>
					<th scope="row">
						<label for="title">
							<?php _e('Fecha de resolución', 'entusiastics-quiz-game')?>:
						</label>
					</th>

					<td>
						<span><?php echo $args['completed']->created_at ?></span>
					</td>

				</tr>
				<tr>
					<th scope="row">
						<label for="title">
							<?php _e('IP', 'entusiastics-quiz-game')?>:
						</label>
					</th>

					<td>
						<span><?php echo $args['completed']->ip ?></span>
					</td>

				</tr>
				<tr>
					<th scope="row">
						<label>
							<?php _e('User ID', 'entusiastics-quiz-game')?>:
						</label>
					</th>

					<td>
						<span><?php echo $args['completed']->user_id == 0 ? _e('Anónimo', 'entusiastics-quiz-game') : $args['completed']->user_id ?></span>
					</td>

				</tr>
				<tr>
					<th scope="row">
						<label>
							<?php _e('Total preguntas Quiz', 'entusiastics-quiz-game')?>:
						</label>
					</th>

					<td>
						<span><?php echo count($args['results']); ?></span>
					</td>

				</tr>
			</tbody>

		</table>

		<h2 class="title">
			<?php _e('Resultados', 'entusiastics-quiz-game') ?>
		</h2>
		
		<div class="entusiastics-result-container">

			<div class="entusiastics-result-wrapper">

				<div class="entusiastics-result-content">
					<input type="hidden" id="minus-info-text" value="<?php _e('Menos info', 'entusiastics-quiz-game'); ?>" />
					<input type="hidden" id="more-info-text" value="<?php _e('Más info', 'entusiastics-quiz-game'); ?>" />

					<?php include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH.'admin/partials/entusiastics-quiz-game-completed-partial-positive.php'); ?>

					<?php include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH.'admin/partials/entusiastics-quiz-game-completed-partial-negative.php'); ?>

					<?php if(!empty($args['results_no_profile'])) {
						include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH.'admin/partials/entusiastics-quiz-game-completed-partial-results_no_profile.php');
					}

					?>

				</div>

			</div>

			<h2 class="title">
				<?php _e('Todos los completados de este Quiz','entusiastics-quiz-game'); ?>
			</h2>

			<form method="post">
				<input type="hidden" id="message_delete" value="<?php _e('Estas seguro?', 'entusiastics-quiz-game')?>">
				<input type="hidden" name="page" value="completed_list_table">
				<?php

				$completed_list_table->search_box( __('Buscar', 'entusiastics-quiz-game'), 'search_id' );

				$completed_list_table->display(); 

				?>
			</form>

		</div>

		<script>
			jQuery(document).ready(function() {

				updateDonutChart('.positive-chart', 25, true);
				updateDonutChart('.negative-chart', 25, true);
				updateDonutChart('.no-profile-chart', 25, true);

				var acc = document.getElementsByClassName("entusiastics-indicator-accordion-button");
				var i;

				for (i = 0; i < acc.length; i++) {

					acc[i].addEventListener("click", function(e) {

						e.preventDefault();

						var text = jQuery(this).children('.entusiastics-indicator-accordion-button-text');
						var icon = jQuery(this).children('.entusiastics-indicator-accordion-button-icon');

						var minus_text = jQuery('#minus-info-text').val();
						var more_text = jQuery('#more-info-text').val();

						jQuery(this).toggleClass("active");

						var panel = jQuery(this).parent().parent().siblings('.entusiastics-indicator-item-bottom').find('.entusiastics-indicator-item-panel');

						if (jQuery(panel).css('max-height') != '0px') {

							jQuery(panel).css('max-height', '0px');
							text.html(more_text);
							icon.text('+');

						} else {

							jQuery(panel).css('max-height', jQuery(panel).prop("scrollHeight") +'px');
							text.html(minus_text);
							icon.text('-');

						}

					});

				}

			});

			// Update Donut Chart
			function updateDonutChart (el, percent, donut) {
				percent = Math.round(percent);
				if (percent > 100) {
					percent = 100;
				} else if (percent < 0) {
					percent = 0;
				}
				var deg = Math.round(360 * (percent / 100));

				if (percent > 50) {
					jQuery(el + ' .pie').css('clip', 'rect(auto, auto, auto, auto)');
					jQuery(el + ' .right-side').css('transform', 'rotate(180deg)');
				} else {
					jQuery(el + ' .pie').css('clip', 'rect(0, 1em, 1em, 0.5em)');
					jQuery(el + ' .right-side').css('transform', 'rotate(0deg)');
				}
				if (donut) {
					jQuery(el + ' .right-side').css('border-width', '0.1em');
					jQuery(el + ' .left-side').css('border-width', '0.1em');
					jQuery(el + ' .shadow').css('border-width', '0.1em');
				} else {
					jQuery(el + ' .right-side').css('border-width', '0.5em');
					jQuery(el + ' .left-side').css('border-width', '0.5em');
					jQuery(el + ' .shadow').css('border-width', '0.5em');
				}
				jQuery(el + ' .num').text(percent);
				jQuery(el + ' .left-side').css('transform', 'rotate(' + deg + 'deg)');
			}
		</script>
	</div>

</div>

<script type="text/javascript" >
	function entusiasticsQuizGameDelete(id) {
		if(confirm("<?php _e('Estas seguro?', 'entusiastics-quiz-game')?>")) {
			window.location = 'admin.php?page=entusiastics-quiz-game-list&quiz_id=<?php echo $quiz->id?>&offset=<?php echo $offset?>&ob=<?php echo $ob?>&dir=<?php echo $dir?>&del=' + id;
		}
	}	
</script>